pub enum RequestError {
    StartLineMissingMethod,
    StartLineMissingTarget,
    TargetTooLong,
    TargetCouldNotParse,
    MethodNotSupported(String),
    QueryParametersCouldNotParse,
}

impl RequestError {
    #[rustfmt::skip]
    pub fn description(&self) -> String {
        match self {
            Self::StartLineMissingMethod => "The request method is missing from the start line".to_string(),
            Self::StartLineMissingTarget => "The request target URI is missing from the start line".to_string(),
            Self::TargetTooLong => "The length of the request target URI in the start line exceeds the maximum length".to_string(),
            Self::TargetCouldNotParse => "The request target URI is invalid".to_string(),
            Self::MethodNotSupported(method) => format!("The '{}' method is not supported", method),
            Self::QueryParametersCouldNotParse => "QueryParametersCouldNotParse".to_string(),
        }
    }
}
