use crate::RequestError;

pub enum Method {
    GET,
    POST,
    PUT,
    PATCH,
    DELETE,
    OPTION,
    HEAD,
}

impl Method {
    pub fn parse(method: &str) -> Result<Self, RequestError> {
        Ok(match method {
            "GET" => Self::GET,
            "POST" => Self::POST,
            "PUT" => Self::PUT,
            "PATCH" => Self::PATCH,
            "DELETE" => Self::DELETE,
            "OPTION" => Self::OPTION,
            "HEAD" => Self::HEAD,
            method => return Err(RequestError::MethodNotSupported(method.to_string())),
        })
    }

    pub fn name(&self) -> &str {
        match self {
            Self::GET => "GET",
            Self::POST => "POST",
            Self::PUT => "PUT",
            Self::PATCH => "PATCH",
            Self::DELETE => "DELETE",
            Self::OPTION => "OPTION",
            Self::HEAD => "HEAD",
        }
    }
}

impl std::fmt::Debug for Method {
    fn fmt(&self, f: &mut std::fmt::Formatter) -> Result<(), std::fmt::Error> {
        write!(f, "{}", self.name())
    }
}
