use crate::*;
use log::info;
use std::collections::HashMap;
use std::net::SocketAddr;
use wetstring::Request;

pub struct HttpRequest {
    pub client_address: SocketAddr,
    pub method: Method,
    pub target: RequestTarget,
    pub headers: HashMap<String, String>,
    pub body: Option<Vec<u8>>,
}

impl Request for HttpRequest {}

pub struct RequestTarget {
    /// `path` excludes host
    pub path: String,
    pub query_parameters: HashMap<String, String>,
}

impl RequestTarget {
    pub fn parse(text: &str) -> Result<Self, RequestError> {
        info!("URI is '{}'", text);
        match text.split_once('?') {
            Some((path, query)) => Ok(Self {
                path: path.to_string(),
                query_parameters: Self::parse_query_parameters(query)?,
            }),
            None => Ok(Self {
                path: text.to_string(),
                query_parameters: HashMap::new(),
            }),
        }
    }

    fn parse_query_parameters(query: &str) -> Result<HashMap<String, String>, RequestError> {
        let mut query_parameters = HashMap::new();
        for pair_text in query.split('&') {
            match pair_text.split_once('=') {
                Some((key, value)) => query_parameters.insert(key.to_string(), value.to_string()),
                None => return Err(RequestError::QueryParametersCouldNotParse),
            };
        }
        return Ok(query_parameters);
    }
}
